# machinic

Utilities typically used across projects and extensions of the python standard library.

Long term goal is to get this package <= 3 dependencies, and accelerate most of the slow code in rust.

## Packages

### Dependencies

...

### Integrated

#### [MIT] [python-case-converter](https://github.com/chrisdoherty4/python-case-converter)

Changes:

- Some modifications made to allow for subclasses of `str` for which the constructor sets the relevant case.
- Additional cases added.
- Type annotations added where missing.
- Other assorted modifications.
- Log statements removed.
- Parametrized whitespace delimiters.


### To Integrate

#### [MIT] [more-itertools](https://github.com/more-itertools/more-itertools)


<!--
Maybe will add, but probably split into separate project:

- [cryptography](https://github.com/pyca/cryptography)
- [scipy](https://github.com/scipy/scipy)
- [sympy](https://github.com/sympy/sympy)
- [numpy](https://github.com/numpy/numpy)
- [pendulum](?)

## References

- [superstring]()
- [adict]()

-->